/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import {
  faAngellist,
  faBluesky,
  faDiscord,
  faFreeCodeCamp,
  faGithub,
  faGooglePlus,
  faHashnode,
  faInstagram,
  faItchIo,
  faLinkedinIn,
  faMastodon,
  faMeetup,
  faNpm,
  faPatreon,
  faPaypal,
  faProductHunt,
  faReddit,
  faSignalMessenger,
  faSlack,
  faSteam,
  faStripe,
  faTelegramPlane,
  faThreads,
  faTiktok,
  faTumblr,
  faTwitch,
  faWhatsapp,
  faWordpress,
  faYoutube,
  faSnapchat,
  faXTwitter,
} from "@fortawesome/free-brands-svg-icons";
import {
  faAtom,
  faBriefcase,
  faChessKnight,
  faComputer,
  faEnvelope,
  faGamepad,
  faHashtag,
  faMoneyBill,
} from "@fortawesome/free-solid-svg-icons";
import { Codeberg } from "../icons/Codeberg";
import { Coursera } from "../icons/Coursera";
import { Fiverr } from "../icons/Fiverr";
import { Gather } from "../icons/Gather";
import { Gog } from "../icons/Gog";
import { Gumroad } from "../icons/Gumroad";
import { Kofi } from "../icons/KoFi";
import { Matrix } from "../icons/Matrix";
import { Peerlist } from "../icons/Peerlist";
import { Pixiv } from "../icons/Pixiv";
import { Polywork } from "../icons/Polywork";
import { RetroAchievements } from "../icons/RetroAchievements";
import { Saylor } from "../icons/Saylor";
import { TeeSpring } from "../icons/TeeSpring";
import { Throne } from "../icons/Throne";
import { Topmate } from "../icons/Topmate";
import { TreeNation } from "../icons/TreeNation";
import { Udemy } from "../icons/Udemy";
import { VRoid } from "../icons/VRoid";
import type { IconDefinition } from "@fortawesome/fontawesome-svg-core";

/**
 * Custom button with gradient for hire CTA.
 */
const HireMe: {
  icon:       IconDefinition;
  link:       string;
  label:      string;
  alt:        string;
  color:      string;
  background: string;
} = {
  alt:        "Briefcase Icon",
  background: `linear-gradient(
              90deg,
              #5bcefa,
              #f5a9b8,
              #ffffff,
              #f5a9b8,
              #5bcefa
            )`,
  color: "#003600",
  icon:  faBriefcase,
  label: "Hire Us!",
  link:  "https://docs.nhcarrigan.com/about/hire/",
};

/**
 * Custom button with gradient for Donate CTA.
 */
const Donate: {
  icon:       IconDefinition;
  link:       string;
  label:      string;
  alt:        string;
  color:      string;
  background: string;
} = {
  alt:        "Money Icon",
  background: `linear-gradient(
              90deg,
              rgba(255, 0, 0, 1) 0%,
              rgba(251, 7, 217, 1) 10%,
              rgba(186, 12, 248, 1) 20%,
              rgba(95, 21, 242, 1) 30%,
              rgba(28, 127, 238, 1) 40%,
              rgba(47, 201, 226, 1) 50%,
              rgba(63, 218, 216, 1) 60%,
              rgba(79, 220, 74, 1) 70%,
              rgba(208, 222, 33, 1) 80%,
              rgba(255, 154, 0, 1) 90%,
              rgba(255, 0, 0, 1) 100%
            )`,
  color: "#003600",
  icon:  faMoneyBill,
  label: "Donate 💜",
  link:  "https://docs.nhcarrigan.com/about/donate/",
};

/**
 * List of social media buttons to render.
 */
const Socials: Array<{
  icon:       IconDefinition;
  link:       string;
  label:      string;
  alt:        string;
  color:      string;
  background: string;
}> = [
  {
    alt:        "Codeberg Logo",
    background: "#0B3049",
    color:      "#B5DDFF",
    icon:       Codeberg,
    label:      "Codeberg",
    link:       "https://codeberg.org/naomi-lgbt",
  },
  {
    alt:        "GitHub Logo",
    background: "#333333",
    color:      "#FFFFFF",
    icon:       faGithub,
    label:      "GitHub",
    link:       "https://github.com/nhcarrigan",
  },
  {
    alt:        "Discord Logo",
    background: "#7289DA",
    color:      "#FFFFFF",
    icon:       faDiscord,
    label:      "Discord",
    link:       "https://chat.naomi.lgbt",
  },
  {
    alt:        "Element Logo",
    background: "#29B6F6",
    color:      "#FFFFFF",
    icon:       Matrix,
    label:      "Matrix",
    link:       "https://matrix.to/#/#naomi:matrix.org",
  },
  {
    alt:        "Octothorpe",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faHashtag,
    label:      "IRC",
    link:       "https://docs.nhcarrigan.com/about/contact/#33-irc-channels",
  },
  {
    alt:        "Slack Logo",
    background: "#4A154B",
    color:      "#FFFFFF",
    icon:       faSlack,
    label:      "Slack",
    link:       "https://join.slack.com/t/naomi-lgbt/signup",
  },
  {
    alt:        "Reddit Logo",
    background: "#FF4500",
    color:      "#FFFFFF",
    icon:       faReddit,
    label:      "Reddit",
    link:       "https://reddit.com/r/nhcarrigan",
  },
  {
    alt:        "Hashnode Logo",
    background: "#2962FF",
    color:      "#FFFFFF",
    icon:       faHashnode,
    label:      "Blog",
    link:       "https://blog.nhcarrigan.com",
  },
  {
    alt:        "LinkedIn Logo",
    background: "#0077B5",
    color:      "#FFFFFF",
    icon:       faLinkedinIn,
    label:      "LinkedIn",
    link:       "https://linkedin.com/in/naomi-lgbt",
  },
  {
    alt:        "Peerlist Logo",
    background: "#219653",
    color:      "#FFFFFF",
    icon:       Peerlist,
    label:      "Peerlist",
    link:       "https://resume.nhcarrigan.com",
  },
  {
    alt:        "Polywork Logo",
    background: "#7C3AED",
    color:      "#FFFFFF",
    icon:       Polywork,
    label:      "Polywork",
    link:       "https://polywork.nhcarrigan.com/",
  },
  {
    alt:        "Fiverr Logo",
    background: "#1DBF73",
    color:      "#FFFFFF",
    icon:       Fiverr,
    label:      "Fiverr",
    link:       "https://www.fiverr.com/nhcarrigan",
  },
  {
    alt:        "Mastodon Logo",
    background: "#2B90D9",
    color:      "#FFFFFF",
    icon:       faMastodon,
    label:      "Mastodon",
    link:       "https://mastodon.social/@naomi_lgbt",
  },
  {
    alt:        "X Logo",
    background: "#1DA1F2",
    color:      "#FFFFFF",
    icon:       faXTwitter,
    label:      "X (Twitter)",
    link:       "https://x.com/naomi_lgbt",
  },
  {
    alt:        "Steam Logo",
    background: "#1b2838",
    color:      "#c7d5e0",
    icon:       faSteam,
    label:      "Steam",
    link:       "https://steamcommunity.com/id/naomi-lgbt/",
  },
  {
    alt:        "Twitch Logo",
    background: "#6441A4",
    color:      "#FFFFFF",
    icon:       faTwitch,
    label:      "Twitch",
    link:       "https://www.twitch.tv/naomilgbt/",
  },
  {
    alt:        "How Long to Beat Logo",
    background: "#333333",
    color:      "#FFFFFF",
    icon:       faGamepad,
    label:      "HLTB",
    link:       "https://howlongtobeat.com/user/naomi_lgbt",
  },
  {
    alt:        "Snapchat Logo",
    background: "#FFFC00",
    color:      "#000000",
    icon:       faSnapchat,
    label:      "Snapchat",
    link:       "https://www.snapchat.com/add/naomi-lgbt",
  },
  {
    alt:        "GOG Logo",
    background: "#863A3A",
    color:      "#FFFFFF",
    icon:       Gog,
    label:      "GOG",
    link:       "https://www.gog.com/u/naomi-lgbt",
  },
  {
    alt:        "Itch.io Logo",
    background: "#FA5C5C",
    color:      "#FFFFFF",
    icon:       faItchIo,
    label:      "Itch.io",
    link:       "https://nhcarrigan.itch.io/",
  },
  {
    alt:        "Lichess Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faChessKnight,
    label:      "Lichess",
    link:       "https://lichess.org/../naomi-lgbt",
  },
  {
    alt:        "Saylor Academy Logo",
    background: "#469dcc",
    color:      "#183140",
    icon:       Saylor,
    label:      "Saylor Academy",
    link:       "https://learn.saylor.org/user/profile.php?id=2074619",
  },
  {
    alt:        "Paypal Logo",
    background: "#003087",
    color:      "#FFFFFF",
    icon:       faPaypal,
    label:      "Paypal",
    link:       "https://paypal.me/nhcarrigan",
  },
  {
    alt:        "Ko-Fi Logo",
    background: "#FF5E5B",
    color:      "#FFFFFF",
    icon:       Kofi,
    label:      "Ko-Fi",
    link:       "https://ko-fi.com/nhcarrigan",
  },
  {
    alt:        "Patreon Logo",
    background: "#F96854",
    color:      "#FFFFFF",
    icon:       faPatreon,
    label:      "Patreon",
    link:       "https://patreon.com/nhcarrigan",
  },
  {
    alt:        "freeCodeCamp Logo",
    background: "#0a0a23",
    color:      "#FFFFFF",
    icon:       faFreeCodeCamp,
    label:      "freeCodeCamp",
    link:       "https://forum.freecodecamp.org/u/nhcarrigan/summary",
  },
  {
    alt:        "NPM Logo",
    background: "#CB3837",
    color:      "#FFFFFF",
    icon:       faNpm,
    label:      "NPM",
    link:       "https://www.npmjs.com/~nhcarrigan",
  },
  {
    alt:        "GatherTown Logo",
    background: "#7B68EE",
    color:      "#FFFFFF",
    icon:       Gather,
    label:      "GatherTown",
    link:       "https://app.gather.town/invite?token=CiIvbSnrQiW-akXFSPL_",
  },
  {
    alt:        "VRoid Logo",
    background: "#ffe100",
    color:      "#000000",
    icon:       VRoid,
    label:      "VRoid",
    link:       "https://hub.vroid.com/en/characters/6033404747153826650/models/3483506204509065121",
  },
  {
    alt:        "Pixiv Logo",
    background: "#0096FA",
    color:      "#FFFFFF",
    icon:       Pixiv,
    label:      "Pixiv",
    link:       "https://www.pixiv.net/en/users/77818154",
  },
  {
    alt:        "Email Icon",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faEnvelope,
    label:      "Email",
    link:       "https://docs.nhcarrigan.com/about/contact/#7-email-communication",
  },
  {
    alt:        "Coursera Logo",
    background: "#0056D2",
    color:      "#FFFFFF",
    icon:       Coursera,
    label:      "Coursera",
    link:       "https://www.coursera.org/learner/naomi-lgbt",
  },
  {
    alt:        "Udemy Logo",
    background: "#EC5252",
    color:      "#FFFFFF",
    icon:       Udemy,
    label:      "Udemy",
    link:       "https://www.udemy.com/user/naomi-carrigan/",
  },
  {
    alt:        "Wordpress Logo",
    background: "#1E8EDE",
    color:      "#FFFFFF",
    icon:       faWordpress,
    label:      "Gravatar",
    link:       "https://gravatar.com/nhcarrigan",
  },
  {
    alt:        "Computer Icon",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faComputer,
    label:      "PC Part Picker",
    link:       "https://pcpartpicker.com/user/nhcarrigan/",
  },
  {
    alt:        "Throne.me Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       Throne,
    label:      "Throne",
    link:       "https://throne.com/naomilgbt",
  },
  {
    alt:        "Stripe Logo",
    background: "#6772E5",
    color:      "#FFFFFF",
    icon:       faStripe,
    label:      "Stripe",
    link:       "https://buy.stripe.com/cN24iTfqu1j6b3afZ2",
  },
  {
    alt:        "Signal Logo",
    background: "#FFFFFF",
    color:      "#3A76F0",
    icon:       faSignalMessenger,
    label:      "Signal",
    link:       "https://signal.me/#eu/YGo6ag7kAwkdfkw863-J4qLK3VyKn8uWLhvyX60Jx5J0qrDZnz1B_aLrjM9yAMe6",
  },
  {
    alt:        "Angellist Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faAngellist,
    label:      "WellFound",
    link:       "https://wellfound.com/u/naomi-h-carrigan",
  },
  {
    alt:        "ProtonDB Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faAtom,
    label:      "ProtonDB",
    link:       "https://www.protondb.com/users/1717755560",
  },
  {
    alt:        "TeeSpring Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       TeeSpring,
    label:      "Merch",
    link:       "https://nhcarrigan.creator-spring.com/",
  },
  {
    alt:        "BlueSky Logo",
    background: "#1DA1F2",
    color:      "#FFFFFF",
    icon:       faBluesky,
    label:      "BlueSky",
    link:       "https://bsky.app/profile/naomi.lgbt",
  },
  {
    alt:        "Telegram Logo",
    background: "#0088cc",
    color:      "#FFFFFF",
    icon:       faTelegramPlane,
    label:      "Telegram",
    link:       "https://t.me/naomi_lgbt",
  },
  {
    alt:        "WhatsApp Logo",
    background: "#25D366",
    color:      "#FFFFFF",
    icon:       faWhatsapp,
    label:      "WhatsApp",
    link:       "https://chat.whatsapp.com/JmjRYDvIv5z9ykHDZs2C3Z",
  },
  {
    alt:        "Google Chat Logo",
    background: "#DB4437",
    color:      "#FFFFFF",
    icon:       faGooglePlus,
    label:      "Google Chat",
    link:       "https://chat.google.com/room/AAAAK270m3M",
  },
  {
    alt:        "Tree Nation Logo",
    background: "#FFFFFF",
    color:      "#55C1A8",
    icon:       TreeNation,
    label:      "Tree Nation",
    link:       "https://tree-nation.com/profile/naomi-carrigan",
  },
  {
    alt:        "Meetup Logo",
    background: "#FF6D00",
    color:      "#FFFFFF",
    icon:       faMeetup,
    label:      "Meetup",
    link:       "https://www.meetup.com/members/437962584/",
  },
  {
    alt:        "Tumblr Logo",
    background: "#36465D",
    color:      "#FFFFFF",
    icon:       faTumblr,
    label:      "Tumblr",
    link:       "https://www.tumblr.com/naomi-lgbt",
  },
  {
    alt:        "YouTube Logo",
    background: "#FF0000",
    color:      "#FFFFFF",
    icon:       faYoutube,
    label:      "YouTube",
    link:       "https://www.youtube.com/@naomilgbt",
  },
  {
    alt:        "Tiktok Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faTiktok,
    label:      "Tiktok",
    link:       "https://www.tiktok.com/@naomilgbt",
  },
  {
    alt:        "Threads Logo",
    background: "#000000",
    color:      "#FFFFFF",
    icon:       faThreads,
    label:      "Threads",
    link:       "https://www.threads.net/@naomi.lgbt",
  },
  {
    alt:        "Instagram Logo",
    background: "#C13584",
    color:      "#FFFFFF",
    icon:       faInstagram,
    label:      "Instagram",
    link:       "https://www.instagram.com/naomi.lgbt/",
  },
  {
    alt:        "RetroAchievements Logo",
    background: "#1066dd",
    color:      "#cc9a00",
    icon:       RetroAchievements,
    label:      "RetroAchievements",
    link:       "https://retroachievements.org/user/naomilgbt",
  },
  {
    alt:        "ProductHunt Logo",
    background: "#da552f",
    color:      "#FFFFFF",
    icon:       faProductHunt,
    label:      "ProductHunt",
    link:       "https://www.producthunt.com/@naomi_lgbt",
  },
  {
    alt:        "Topmate Logo",
    background: "#e44332",
    color:      "#FFFFFF",
    icon:       Topmate,
    label:      "Topmate",
    link:       "https://topmate.io/nhcarrigan",
  },
  {
    alt:        "Gumroad Logo",
    background: "#fe90e7",
    color:      "#000000",
    icon:       Gumroad,
    label:      "Gumroad",
    link:       "https://nhcarrigan.gumroad.com",
  },
];

export { HireMe, Donate, Socials };
